# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"base_folder": "00_core.ipynb",
         "simulations_observing_efficiency": "00_core.ipynb",
         "get_telescope": "00_core.ipynb",
         "parse_channels": "00_core.ipynb",
         "s4": "00_core.ipynb",
         "emission_naming": "01_foregrounds.ipynb",
         "load_sky_emission": "01_foregrounds.ipynb",
         "get_telecope_years": "02_atmosphere.ipynb",
         "load_atmosphere": "02_atmosphere.ipynb",
         "thinfp_string": "03_noise.ipynb",
         "thinfp_table": "03_noise.ipynb",
         "get_thinfp": "03_noise.ipynb",
         "get_tube_years": "03_noise.ipynb",
         "load_noise": "03_noise.ipynb",
         "md5sum_string": "04_cli.ipynb",
         "md5sum_file": "04_cli.ipynb",
         "S4RefSimTool": "04_cli.ipynb",
         "command_line_script": "04_cli.ipynb"}

modules = ["core.py",
           "foregrounds.py",
           "atmosphere.py",
           "noise.py",
           "cli.py"]

doc_url = "https://cmb-s4.github.io/s4_design_sim_tool/"

git_url = "https://github.com/cmb-s4/s4_design_sim_tool/tree/master/"

def custom_doc_links(name): return None
